@@ -21,7 +21,8 @@ async def post(path, data=None,
             return result
 
 
-async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False, **kwargs):
+async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False,
+              **kwargs):
     async with aiohttp.ClientSession() as session:
         async with session.get(base_url + path, params=params, **kwargs) as resp:
             if result_type == "json":
@@ -76,28 +77,32 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
 
 
 def eureka_get(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=False, **kwargs):
-    base_url = kwargs.pop("base_url")
+    base_url = tornado.options.options.data_server
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
+
     if tornado.options.options.running_env != "local":
 
         res = eureka_request(path=path, return_type=return_type, method="GET", data=data, app_name=app_name, pack=pack,
                              **kwargs)
     else:
-        res = sync_get(path=path, params=data, base_url=base_url if base_url else tornado.options.options.data_server,
+        res = sync_get(path=path, params=data, base_url=base_url,
                        result_type=return_type,
                        pack=pack, **kwargs)
     return res
 
 
 def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=False, **kwargs):
-    base_url = kwargs.pop("base_url")
+    base_url = tornado.options.options.data_server
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
     if tornado.options.options.running_env != "local":
 
         res = eureka_request(path=path, return_type=return_type, method="POST", data=json.dumps(data),
                              app_name=app_name,
                              pack=pack, **kwargs)
     else:
-
-        res = sync_post(path=path, data=data, base_url=base_url if base_url else tornado.options.options.data_server,
+        res = sync_post(path=path, data=data, base_url=base_url,
                         result_type=return_type,
                         pack=pack, **kwargs)
     return res
